@@ -16,4 +16,4 @@ from .gltf import GLTF, Scene
 from .animations import Animation, Skin
 from .buffers import Buffer, BufferView, Vec2Array, Vec3Array, Vec4Array, ScalarArray, Mat4Array
 from .materials import Material, Texture, Sampler, Image
-from .nodes import Node, Mesh, Primitive
+from .nodes import Node, Mesh, Primitive, Attributes
