@@ -169,17 +169,19 @@ class Accessor(BaseGLTFStructure):
                 raise ValueError('Accessor count does not match! Expected {}, got {}'
                                  ''.format(data['count'], self.count))
 
-            if None in data['min']:
-                logger.warning('Accessor minimum was not a number!')
-            elif 'min' in data and not np.allclose(data['min'], self.min, rtol=1e-07):
-                logger.warning('Accessor minimum did not match! Expected {}, got {}'
-                               ''.format(data['min'], self.min))
+            if 'min' in data:
+                if None in data['min']:
+                    logger.warning('Accessor minimum was not a number!')
+                elif not np.allclose(data['min'], self.min, rtol=1e-07):
+                    logger.warning('Accessor minimum did not match! Expected {}, got {}'
+                                   ''.format(data['min'], self.min))
 
-            if None in data['max']:
-                logger.warning('Accessor maximum was not a number!')
-            elif 'max' in data and not np.allclose(data['max'], self.max, rtol=1e-07):
-                logger.warning('Accessor maximum did not match! Expected {}, got {}'
-                               ''.format(data['max'], self.max))
+            if 'max' in data:
+                if None in data['max']:
+                    logger.warning('Accessor maximum was not a number!')
+                elif not np.allclose(data['max'], self.max, rtol=1e-07):
+                    logger.warning('Accessor maximum did not match! Expected {}, got {}'
+                                   ''.format(data['max'], self.max))
         else:
             self.data = [] if data is None else data
 
