@@ -18,7 +18,7 @@ import logging
 import math
 
 import numpy as np
-from PIL import Image as PImage
+from PIL import Image as PImage, ImageDraw
 
 from .buffers import Vec2Array, Vec3Array
 
@@ -145,7 +145,7 @@ def reindex_primitive(p):
 
     for index in p.indices.data:
         pos = tuple(p.positions.data[index].tolist())
-        norm = tuple(p.normals.data[index].tolist())
+        norm = tuple(p.normals.data[index].tolist()) if p.normals else None
         # TODO: handle multiple texcoord sets
         uv = (
             None if not p.texcoords else
@@ -681,7 +681,7 @@ def repair(model, trim_to_scene=None):
         for primitive in mesh.primitives:
             primitive.sort_joints()
 
-            if not primitive.indices:
+            if not primitive.indices and not primitive.targets:
                 reindex_primitive(primitive)
 
             # get all used materials
@@ -827,3 +827,49 @@ def center(model):
         logger.info('Centering model using translation: '
                     '' + ', '.join(map(str, translation)))
         model.add_root_transform(transformation)
+
+
+def get_texture_efficiency(model):
+    ims = {
+        im: PImage.new('L', im.get_pil_image().size)
+        for im in model.images
+    }
+    draws = {
+        im: ImageDraw.Draw(ims[im])
+        for im in model.images
+    }
+
+    # TODO: only iterate over meshes that are actually used?
+    for m in model.meshes:
+        for p in m.primitives:
+            if not p.material or not p.texcoords:
+                continue
+
+            # TODO: handle secondary UV set when specified?
+            textures = [t for t in [p.material.color_texture, p.material.rough_metal_texture,
+                                    p.material.normal_texture, p.material.occlusion_texture,
+                                    p.material.emissive_texture] if t is not None]
+            if not textures:
+                continue
+
+            texcoords = p.texcoords[0].data
+            indices = p.indices.data if p.indices else list(range(texcoords.count))
+            tri = []
+            for i in indices:
+                tri.append(texcoords[i])
+                if len(tri) == 3:
+                    for t in textures:
+                        draw = draws[t.source]
+                        size = ims[t.source].size
+                        # TODO: handle texture wrapping? or is this enough?
+                        draw.polygon([((v[0] % 1) * size[0], (v[1] % 1) * size[1]) for v in tri], fill='white')
+                    tri = []
+
+    efficiencies = []
+    for i, t in enumerate(model.textures):
+        im = ims[t.source]
+        utilization = sum(im.point(bool).getdata()) / (im.size[0] * im.size[1])
+        efficiencies.append(utilization)
+        print(f'Texture {i}: {utilization:.0%}')
+
+    return efficiencies
